@@ -4,16 +4,21 @@ use strict;
 use vars qw[ $VERSION ];
 use JavaScript::Code::Expression::Op::Term;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 sub new {
     my $obj   = shift;
     my $class = ref $obj || $obj;
 
+    die("'$class' is a binary operator and must take exactly 2 operands.")
+      unless @_ == 2;
+
     return bless [@_], $class;
 }
 
-sub children { @{ shift() } }
+sub children { return @{ shift() } }
+
+sub unary { return 0; }
 
 sub output {
     my ( $self, $precedence ) = @_;
